==> galeon-0.12.4.tar.gz: galeon-0.12.4/src/mozcallbacks.h <==
/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtkmozembed.h>

void new_window_orphan_cb (GtkMozEmbedSingle *embed,
			   GtkMozEmbed **retval, guint chromemask,
			   gpointer data);
void mozembed_new_window_cb (GtkMozEmbed *dummy, GtkMozEmbed **retval,
			     guint chromemask, GaleonEmbed *embed);
void mozembed_visibility_cb (GtkMozEmbed *dummy, gboolean visibility,
			     GaleonEmbed *embed);
void mozembed_destroy_brsr_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void destroy_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_location_changed_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_title_changed_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_load_started_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_load_finished_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_progress_change_cb (GtkMozEmbed *dummy, gint cur, gint max,
				  GaleonEmbed *embed);
void mozembed_link_message_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_js_status_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_net_status_change_cb (GtkMozEmbed *dummy, gint flags,
				    guint status, GaleonEmbed *embed);
gint mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				  GaleonEmbed *embed);
gint mozembed_dom_mouse_down_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				 GaleonEmbed *embed);
gint mozembed_dom_mouse_up_cb (GtkMozEmbed *dummy, gpointer dom_event, 
			       GaleonEmbed *embed);
gint mozembed_dom_mouse_over_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				 GaleonEmbed *embed);
gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				GaleonEmbed *embed);
void mozembed_size_to_cb (GtkMozEmbed *dummy, gint width, gint height, 
			  GaleonEmbed *embed);
gboolean mozembed_drag_drop_cb (GtkWidget *widget, GdkDragContext *context, 
				gint x, gint y, 
				GtkSelectionData *selection_data, 
				guint info, guint time);
void mozembed_security_change_cb (GtkMozEmbed *dummy, gpointer request,
				  guint state, GaleonEmbed *embed);

==> galeon_1.2.0.orig.tar.gz: galeon-1.2.0/src/mozcallbacks.h <==
/*
 *  Copyright (C) 2000 Marco Pesenti Gritti
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtkmozembed.h>

void new_window_orphan_cb (GtkMozEmbedSingle *embed,
			   GtkMozEmbed **retval, guint chromemask,
			   gpointer data);
void mozembed_new_window_cb (GtkMozEmbed *dummy, GtkMozEmbed **retval,
			     guint chromemask, GaleonEmbed *embed);
void mozembed_visibility_cb (GtkMozEmbed *dummy, gboolean visibility,
			     GaleonEmbed *embed);
void mozembed_destroy_brsr_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void destroy_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_location_changed_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_title_changed_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_load_started_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_load_finished_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_progress_change_cb (GtkMozEmbed *dummy, gint cur, gint max,
				  GaleonEmbed *embed);
void mozembed_link_message_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_js_status_cb (GtkMozEmbed *dummy, GaleonEmbed *embed);
void mozembed_net_status_change_cb (GtkMozEmbed *dummy, const char *uri,
				    gint flags, guint status,
				    GaleonEmbed *embed);
gint mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				  GaleonEmbed *embed);
gint mozembed_dom_mouse_down_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				 GaleonEmbed *embed);
gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event, 
				GaleonEmbed *embed);
void mozembed_size_to_cb (GtkMozEmbed *dummy, gint width, gint height, 
			  GaleonEmbed *embed);
gboolean mozembed_drag_drop_cb (GtkWidget *widget, GdkDragContext *context, 
				gint x, gint y, 
				GtkSelectionData *selection_data, 
				guint info, guint time);
void mozembed_security_change_cb (GtkMozEmbed *dummy, gpointer request,
				  guint state, GaleonEmbed *embed);
void mozembed_gesture_disconnect (GaleonEmbed *embed);
void mozembed_destroy_cb (GtkObject *object, GaleonEmbed *embed);
